@@ -1,6 +1,6 @@
 ;;; parser-generator-lr.el --- LR(k) Parser Generator -*- lexical-binding: t -*-
 
-;; Copyright (C) 2020-2022  Free Software Foundation, Inc.
+;; Copyright (C) 2020-2024  Free Software Foundation, Inc.
 
 
 ;;; Commentary:
@@ -1028,7 +1028,8 @@
      lr-item-sets
      &optional signal-on-false
      )
-  "Return whether the set collection LR-ITEM-SETS is valid or not, optionally SIGNAL-ON-FALSE."
+  "Return whether the set collection LR-ITEM-SETS is
+valid or not, optionally SIGNAL-ON-FALSE."
   (parser-generator--debug
    (message "lr-item-sets: %s" lr-item-sets))
   (let ((valid-p t)
@@ -1226,7 +1227,9 @@
     valid-p))
 
 (defun parser-generator-lr--action-takes-precedence-p (symbol a-production-number &optional b-production-number)
-  "Return t if reduce action of SYMBOL at A-PRODUCTION-NUMBER takes precedence over shift action.  Optionally is b is a reduction at at B-PRODUCTION-NUMBER."
+  "Return t if reduce action of SYMBOL at A-PRODUCTION-NUMBER
+takes precedence over shift action.
+Optionally is b is a reduction at at B-PRODUCTION-NUMBER."
   (let* ((a-precedence-type
           (parser-generator-lr--get-symbol-precedence-type
            symbol))
@@ -1680,17 +1683,16 @@
      input-tape-index
      pushdown-list
      output
-     translation
-     history)
-  "Perform a LR-parse via lex-analyzer, optionally at INPUT-TAPE-INDEX with PUSHDOWN-LIST, OUTPUT, TRANSLATION and HISTORY."
+     translation)
+  "Perform a LR-parse via lex-analyzer, optionally at
+INPUT-TAPE-INDEX with PUSHDOWN-LIST, OUTPUT, TRANSLATION."
   (let ((result
          (parser-generator-lr--parse
           nil
           input-tape-index
           pushdown-list
           output
-          translation
-          history)))
+          translation)))
     (nth 0 result)))
 
 (defun parser-generator-lr-translate
@@ -1698,17 +1700,16 @@
      input-tape-index
      pushdown-list
      output
-     translation
-     history)
-  "Perform a LR-parse via lex-analyzer, optionally at INPUT-TAPE-INDEX with PUSHDOWN-LIST, OUTPUT, TRANSLATION and HISTORY."
+     translation)
+  "Perform a LR-parse via lex-analyzer, optionally at
+INPUT-TAPE-INDEX with PUSHDOWN-LIST, OUTPUT, TRANSLATION."
   (let ((result
          (parser-generator-lr--parse
           t
           input-tape-index
           pushdown-list
           output
-          translation
-          history)))
+          translation)))
     (nth 1 result)))
 
 ;; Algorithm 5.7, p. 375
@@ -1719,9 +1720,12 @@
      pushdown-list
      output
      translation
-     translation-symbol-table-list
-     history)
-  "Perform a LR-parse via lex-analyzer, optionally PERFORM-SDT means to perform syntax-directed translation and optioanlly start at INPUT-TAPE-INDEX with PUSHDOWN-LIST, OUTPUT, TRANSLATION, TRANSLATION-SYMBOL-TABLE-LIST and HISTORY."
+     translation-symbol-table-list)
+  "Perform a LR-parse via lex-analyzer,
+optionally PERFORM-SDT means to perform
+syntax-directed translation and optionally start
+at INPUT-TAPE-INDEX with PUSHDOWN-LIST,
+OUTPUT, TRANSLATION, TRANSLATION-SYMBOL-TABLE-LIST."
   (unless input-tape-index
     (setq input-tape-index 1))
   (unless pushdown-list
@@ -1754,35 +1758,9 @@
     (unless parser-generator-lr--distinct-goto-tables
       (error "Missing distinct GOTO-tables for grammar!"))
 
-    (let ((accept)
-          (pre-index 0))
+    (let ((accept))
       (while (not accept)
 
-        ;; Save history when index has changed to enable incremental parsing / translating
-        (when
-            (>
-             parser-generator-lex-analyzer--index
-             pre-index)
-          ;; We make a copy of the hash-table here to avoid passing same
-          ;; hash-table every-time with pointer
-          (let ((translation-symbol-table-list))
-            (maphash
-             (lambda (key value)
-               (push
-                `(,key ,value)
-                translation-symbol-table-list))
-             translation-symbol-table)
-            (push
-             `(,parser-generator-lex-analyzer--index
-               ,pushdown-list
-               ,output
-               ,translation
-               ,translation-symbol-table-list)
-             history)
-            (setq
-             pre-index
-             parser-generator-lex-analyzer--index)))
-
         ;; (1) The look-ahead string u, consisting of the next k input symbols, is determined.
         (let ((look-ahead
                (parser-generator-lex-analyzer--peek-next-look-ahead))
@@ -2201,8 +2179,6 @@
            "Parsed entire string without getting accepting! Output: %s"
            (reverse output))
           (reverse output)))))
-    (when history
-      (setq history (reverse history)))
     (when output
       (setq output (reverse output)))
     (let ((translation-symbol-table-list))
@@ -2216,8 +2192,7 @@
       (list
        output
        translation
-       translation-symbol-table-list
-       history))))
+       translation-symbol-table-list))))
 
 (provide 'parser-generator-lr)
 
